==> pytdeextensions-trinity-14.0.13.tar.xz: pytdeextensions-trinity-14.0.13/app_templates/kdeapp/setup.py <==
#!/usr/bin/python
###########################################################################
# setup - description                                                     #
# ------------------------------                                          #
# begin     : Fri Jun 27 2003                                             #
# copyright : (C) 2003-2004 by AUTHOR                                     #
# email     : YOUR@EMAIL.com                                              #
#                                                                         #
###########################################################################
#                                                                         #
#   This program is free software; you can redistribute it and/or modify  #
#   it under the terms of the GNU General Public License as published by  #
#   the Free Software Foundation; either version 2 of the License, or     #
#   (at your option) any later version.                                   #
#                                                                         #
###########################################################################

import tdedistutils

tdedistutils.setup(name="kdeapp",
    version="0.1.0",
    author="AUTHOR",
    author_email="YOUR@EMAIL.com",
    url="http://www.KDEAPP.com/",
    min_kde_version = "3.0.0",
    min_qt_version = "3.0.0",
    license = "GPL",
    application_data = ['src/kdeapp.py','src/prefdialog.py','src/kdeappview.py'],
    executable_links = [('kdeapp','kdeapp.py')],
    docbooks = [ ('doc/en','en') ] )

==> pytdeextensions-trinity-14.1.5.tar.xz: pytdeextensions-trinity-14.1.5/app_templates/kdeapp/setup.py <==
#!/usr/bin/python
###########################################################################
# setup - description                                                     #
# ------------------------------                                          #
# begin     : Fri Jun 27 2003                                             #
# copyright : (C) 2003-2004 by AUTHOR                                     #
# email     : YOUR@EMAIL.com                                              #
#                                                                         #
###########################################################################
#                                                                         #
#   This program is free software; you can redistribute it and/or modify  #
#   it under the terms of the GNU General Public License as published by  #
#   the Free Software Foundation; either version 2 of the License, or     #
#   (at your option) any later version.                                   #
#                                                                         #
###########################################################################

import tdedistutils

tdedistutils.setup(name="kdeapp",
    version="0.1.0",
    author="AUTHOR",
    author_email="YOUR@EMAIL.com",
    url="http://www.KDEAPP.com/",
    min_kde_version = "3.0.0",
    min_tqt_version = "3.0.0",
    license = "GPL",
    application_data = ['src/kdeapp.py','src/prefdialog.py','src/kdeappview.py'],
    executable_links = [('kdeapp','kdeapp.py')],
    docbooks = [ ('doc/en','en') ] )
